protocol library

Classes

BulkData
BulkQueryColumnDescription
BulkQueryResult
ColumnDefinition
The definition of a (desired) column in the database.
ColumnMigration
DatabaseDefinition
Defines the structure of the database used by Serverpod.
DatabaseDefinitions
Defines the current state of the database, including information about installed modules and migrations.
DatabaseMigration
DatabaseMigrationAction
DatabaseMigrationVersionModel
Represents a version of a database migration.
DatabaseMigrationWarning
Filter
FilterConstraint
ForeignKeyDefinition
Represents a foreign key.
IndexDefinition
The definition of a (desired) index in the database.
IndexElementDefinition
Defines an element of an index.
TableDefinition
The definition of a (desired) table in the database.
TableMigration

Enums

ColumnType
All the types, that are possible for columns. Contains all the values of TypeDefinition.databaseType
DatabaseMigrationActionType
DatabaseMigrationWarningType
EnumSerialization
FilterConstraintType
ForeignKeyAction
Describes how to react if the row a foreign key refers to changes / is deleted.
ForeignKeyMatchType
Defines how a foreign key should be matched.
IndexElementDefinitionType
Used to specify how the definition of an IndexElementDefinition should be interpreted.
VectorDistanceFunction
Vector distance functions exposed by pgvector.

Exceptions / Errors

BulkDataException