GinOperatorClass enum
Operator classes used by GIN indexes. See: https://www.postgresql.org/docs/current/gin.html#GIN-BUILTIN-OPCLASSES
Values
- arrayOps → const GinOperatorClass
- jsonbOps → const GinOperatorClass
- jsonbPathOps → const GinOperatorClass
- tsvectorOps → const GinOperatorClass
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Returns a serialized JSON structure of the model which also includes fields used by the database.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
String name) → GinOperatorClass
Constants
-
values
→ const List<
GinOperatorClass> - A constant List of the values in this enum, in order of their declaration.