IndexElementDefinition class abstract

Defines an element of an index.

Available extensions

Constructors

IndexElementDefinition({required IndexElementDefinitionType type, required String definition})
factory
IndexElementDefinition.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

definition String
Depending on the type, this is either a column name or an expression.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type IndexElementDefinitionType
The type of this index element.
getter/setter pair

Methods

copyWith({IndexElementDefinitionType? type, String? definition}) IndexElementDefinition
Returns a shallow copy of this IndexElementDefinition with some or all fields replaced by the given arguments.
like(IndexElementDefinition other) List<IndexComparisonWarning>

Available on IndexElementDefinition, provided by the IndexElementDefinitionComparison extension

Compares this index element with other, returning a list of mismatches.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited