toJson abstract method
dynamic
toJson()
inherited
Returns a serialized JSON structure of the model which also includes fields used by the database.
Implementation
dynamic toJson();
Returns a serialized JSON structure of the model which also includes fields used by the database.
dynamic toJson();