EmbeddedPostgresStartupException class final
An embedded database startup failure that has already been translated into user-facing guidance.
- Implemented types
Constructors
- EmbeddedPostgresStartupException(String message, {required bool includeStackTrace})
-
Creates a user-facing embedded database startup failure.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeStackTrace → bool
-
Whether the original stack trace should be shown for issue reporting.
final
- message → String
-
Message that can be shown directly to a Serverpod user.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited