stop property
Stops the postmaster this call launched, or null when it attached to one
another supervisor already owns. Only invoke it for a non-null value.
Implementation
final Future<void> Function()? stop;
Stops the postmaster this call launched, or null when it attached to one
another supervisor already owns. Only invoke it for a non-null value.
final Future<void> Function()? stop;