shouldReportEmbeddedPostgresFailure function
Whether error should be accompanied by its diagnostic details and stack
trace when shown to a Serverpod user for issue reporting.
Implementation
bool shouldReportEmbeddedPostgresFailure(Object error) => switch (error) {
BinaryFetchException(kind: BinaryFetchFailureKind.download) ||
UnsupportedPlatformException() ||
UnsupportedVersionException() ||
PostmasterLockBusyException() ||
StaleClusterException() ||
AttachException() => false,
_ => true,
};