DeferrableConstraint enum
Defines whether a foreign key constraint is deferrable and, if so, when it is checked by default.
Values
- initiallyImmediate → const DeferrableConstraint
-
The constraint is
DEFERRABLE INITIALLY IMMEDIATE. It is checked after each statement by default, but can be deferred until commit within a transaction (for example withSET CONSTRAINTS ALL DEFERRED). - initiallyDeferred → const DeferrableConstraint
-
The constraint is
DEFERRABLE INITIALLY DEFERRED. It is checked at transaction commit time by default.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Returns a serialized JSON structure of the model which also includes fields used by the database.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
String name) → DeferrableConstraint
Constants
-
values
→ const List<
DeferrableConstraint> - A constant List of the values in this enum, in order of their declaration.